﻿/* DNN TurboOptimizeDNNSettings Version 0.9.5 (2014-10-08)
   ================================================================================
   (c) Sebastian Leupold, dnnWerk/gamma concept mbH 2014

   Run this Script to configure DNN Platform V.7 for optimal performance.
      
   == Please make sure to use latest version from http://dnnscript.codeplex.com ===
   
   Instructions:
   =============
   - Install by running as script from SQL item in Host menu inside DNN or run in 
     SQL Server Management Studio.

   - Make sure that the currently used account is member of dbOwner database role.
   
   License and Disclaimer:
   =======================
   Published under Microsoft Open Source Reciprocal License (Ms-RL). For details, 
   please read http://dnnscript.codeplex.com/license.
   Feel free to use this script as you need, but there is no warranty or liability 
   for any damage or effort, eventually been caused.

   Please report issues at https://dnnscript.codeplex.com/WorkItem/Create
   ================================================================================
*/


UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'MemoryModuleCachingProvider' , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'ModuleCaching'      	      AND [SettingValue] <> 'MemoryModuleCachingProvider';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = '5'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'AuthenticatedCacheability' AND [SettingValue] <> '5';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = '6'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'PerformanceSetting' 	      AND [SettingValue] <> '6';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = '1'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'SchedulerMode'      	      AND [SettingValue] <> '1';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'N'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'CheckUpgrade'       	      AND [SettingValue] <> 'N';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'Y'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'CDNEnabled'         	      AND [SettingValue] <> 'Y';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'Y'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EnableTelerikCDN'   	      AND [SettingValue] <> 'Y';
UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'Y'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EnableMsAjaxCDN'    	      AND [SettingValue] <> 'Y';

-- guess best value for event log buffering
DECLARE @MinDate    Date;
DECLARE @ECount     Int;
DECLARE @days       Int;
DECLARE @TotalCount Int;
SELECT @TotalCount = Count(1)           FROM {databaseOwner}[{objectQualifier}EventLog];
SELECT @MinDate    = Min(LogCreateDate) FROM {databaseOwner}[{objectQualifier}EventLog];
SET @days = DateDiff(d, GetDate(), IsNull(@MinDate, GetDate()));
IF  @days = 0 SET @days = 1;
IF  @ECount / @days > 500 BEGIN -- Enable EventLog Buffer
   UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'Y'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EventLogBuffer'     	   AND [SettingValue] <> 'Y';
   UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = '10'                          , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'SiteLogBuffer'      	   AND [SettingValue] <  '10';
END ELSE
   UPDATE {databaseOwner}[{objectQualifier}HostSettings] SET [SettingValue] = 'N'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EventLogBuffer'     	   AND [SettingValue] <> 'Y';

-- Execute the following statements, if your site log grows too big:
-- UPDATE {databaseOwner}[{objectQualifier}HostSettings]   SET [SettingValue] = '90'                          , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'SiteLogHistory'     	   AND [SettingValue]  > '90';
-- UPDATE {databaseOwner}[{objectQualifier}Portals]        SET [SiteLogHistory] = 90                          , [LastModifiedOnDate] = GetDate() WHERE [SiteLogHistory] > 90;


-- Execute the following statement, if you don't upload files to website documents folder outside of DNN (using FTP, WebDAV, RDP etc.)
-- UPDATE {databaseOwner}[{objectQualifier}HostSettings]   SET [SettingValue] = 'N'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EnableFileAutoSync' 	   AND [SettingValue] <> 'N';

-- Execute the following statement, if you don't expect issues with composite JS and CSS files (depends on the skin and modules being used):
-- UPDATE {databaseOwner}[{objectQualifier}HostSettings]   SET [SettingValue] = 'True'                        , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'CrmEnableCompositeFiles'   AND [SettingValue] <> 'True';

-- Execute the following statement, if the skins of any of your sites don't use any widgets:
-- UPDATE {databaseOwner}[{objectQualifier}PortalSettings] SET [SettingValue] = 'N'                           , [LastModifiedOnDate] = GetDate() WHERE [SettingName] = 'EnableSkinWidgets'    	   AND [SettingValue] <> 'N';

GO


-- evaluate (and correct) Size of SiteLog table:
DECLARE @totalCount    Int;
DECLARE @YearCount     Int;
DECLARE @QuarterCount  Int;
DECLARE @MonthCount    Int;
DECLARE @MinID		   Int;

SELECT @MonthCount    = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] > DateAdd(Month, -1, GetDate());
SELECT @QuarterCount  = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] > DateAdd(Month, -3, GetDate());
SELECT @YearCount     = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] > DateAdd(Year,  -1, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog];
IF @TotalCount >  100000 AND @TotalCount > @YearCount -- delete items older than a year
	DELETE FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] < DateAdd(Year,  -1, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog];
IF @TotalCount >  300000 AND @TotalCount > @QuarterCount -- delete items older than a quarter
	DELETE FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] < DateAdd(Month,  -3, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog];
IF @TotalCount >  500000 AND @TotalCount > @MonthCount -- delete items older than a month
	DELETE FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE [DateTime] < DateAdd(Month,  -1, GetDate());

-- just keep last 500 000 rows
SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}SiteLog];
IF @TotalCount >  500000 BEGIN
	SELECT @MinID = Min(SiteLogID) FROM (SELECT Top (500000) SiteLogID FROM {databaseOwner}[{objectQualifier}SiteLog] ORDER BY SiteLogID DESC) S;
	DELETE FROM {databaseOwner}[{objectQualifier}SiteLog] WHERE SiteLogID < @MinID;
END;
GO


-- evaluate Size of EventLog table:
DECLARE @totalCount    Int;
DECLARE @YearCount     Int;
DECLARE @QuarterCount  Int;
DECLARE @MonthCount    Int;
DECLARE @MinID		   Int;

SELECT @MonthCount    = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate > DateAdd(Month, -1, GetDate());
SELECT @QuarterCount  = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate > DateAdd(Month, -3, GetDate());
SELECT @YearCount     = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate > DateAdd(Year,  -1, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog];
IF @TotalCount >  1000 AND @TotalCount > @YearCount -- delete items older than a year
	DELETE FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate < DateAdd(Year,  -1, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog];
IF @TotalCount >  3000 AND @TotalCount > @QuarterCount -- delete items older than a quarter
	DELETE FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate < DateAdd(Month,  -3, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog];
IF @TotalCount >  5000 AND @TotalCount > @MonthCount -- delete items older than a month
	DELETE FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogCreateDate < DateAdd(Month,  -1, GetDate());

-- just keep last 5000 rows
SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}EventLog];
IF @TotalCount >  5000 BEGIN
	SELECT @MinID = Min(LogEventID) FROM (SELECT Top (5000) LogEventID FROM {databaseOwner}[{objectQualifier}EventLog] ORDER BY LogEventID DESC) S;
	DELETE FROM {databaseOwner}[{objectQualifier}EventLog] WHERE LogEventID < @MinID;
END;
GO

-- evaluate (and adjust) size of ScheduleHistory table:
DECLARE @totalCount    Int;
DECLARE @YearCount     Int;
DECLARE @QuarterCount  Int;
DECLARE @MonthCount    Int;
DECLARE @MinID		   Int;

SELECT @MonthCount    = Count(1) FROM {databaseOwner}[{objectQualifier}ScheduleHistory] WHERE [StartDate] > DateAdd(Month, -1, GetDate());

SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}ScheduleHistory];
IF @TotalCount >  1000 AND @TotalCount > @MonthCount -- delete items older than a month
	DELETE FROM {databaseOwner}[{objectQualifier}ScheduleHistory] WHERE StartDate < DateAdd(Month,  -1, GetDate());

-- just keep last 1000 rows
SELECT @TotalCount    = Count(1) FROM {databaseOwner}[{objectQualifier}ScheduleHistory];
IF @TotalCount >  1000 BEGIN
	SELECT @MinID = Min(ScheduleHistoryID) FROM (SELECT Top (1000) ScheduleHistoryID FROM {databaseOwner}[{objectQualifier}ScheduleHistory] ORDER BY ScheduleHistoryID DESC) S;
	DELETE FROM {databaseOwner}[{objectQualifier}ScheduleHistory] WHERE ScheduleHistoryID < @MinID;
END;
GO

-- optimize module caching:
MERGE INTO {databaseOwner}[{objectQualifier}TabModules] T 
USING {databaseOwner}[{objectQualifier}vw_Modules] M ON (T.TabModuleID = M.TabModuleID)
WHEN MATCHED AND T.CacheMethod <> '' AND T.CacheTime < DefaultCacheTime THEN UPDATE SET T.CacheMethod = '', T.CacheTime = DefaultCacheTime;

-- optimize scheduler frequencies:
-- // TODO
GO